//sci.h
#include "sci.h"
#include <iotms470r1a256.h>

///SCI1
void InitSCI1() {

  // Reset SCI state machine
  SCI1CTL3 &= ~0x80;

  // Idle-line mode, 1 stop bit, no parity, async mode, 8 bits
  SCI1CCR = 0x17;

  // Receiver enble, Idle state, DMA disable
  SCI1CTL1 |= 0x01;

  // Tranmiter enble, DMA disable, Loop-back disable
  SCI1CTL2 |= 0x81;

  // Internal clock. RX interrrupt. TX interrupt.
  SCI1CTL3 |= 0x20 + 0x10 + 0x08;

  // ICLK 12 MHZ
  // SCI2BAUD = ICLK/8*9600+1 = 157  (0x9d)
  SCI1HBAUD = 0x0;
  SCI1MBAUD = 0x0;
  SCI1LBAUD = 0x9d;

  //Rx pin assign to Reveiver
  SCI1PC2_bit.RX_FUNC = 1;
  // Tx pin assign to Transmitter
  SCI1PC3_bit.TX_FUNC = 1;

  // Configure SCI1 state machine
  SCI1CTL3 |= 0x80;

  //////////////////////////////
  /// This is necessary because Led STAT is connected to SCI1CLK
  SCI1PC1_bit.CLK_FUNC      = 0; // CLK is assign as IO
  SCI1PC1_bit.CLK_DATA_DIR  = 1; // CLK as output

}

// Write char to SCI
void SCI1_write_char(unsigned char ch) {
  while(!SCI1CTL2_bit.TXRDY);
  SCI1TXBUF = ch;
}

// Read char from SCI
unsigned char SCI1_read_char(void) {
  unsigned char ch = 0x0;
  while(!SCI1CTL1_bit.RXRDY);
  ch = SCI1RXBUF;
  return ch;
}

// Read char without stop
unsigned char SCI1_read_char_nonstop(void) {
  if(SCI1CTL1_bit.RXRDY)
    return SCI1RXBUF;
  else return 0;
}



/// SCI2
void InitSCI2() {

  // Reset SCI state machine
  SCI2CTL3 &= ~0x80;

  // Idle-line mode, 1 stop bit, no parity, async mode, 8 bits
  SCI2CCR = 0x17;

  // Receiver enble, Idle state, DMA disable
  SCI2CTL1 |= 0x01;

  // Tranmiter enble, DMA disable, Loop-back disable
  SCI2CTL2 |= 0x81;

  // Internal clock. RX interrrupt. TX interrupt.
  SCI2CTL3 |= 0x20 + 0x10 + 0x08;

  // ICLK 12 MHZ
  // SCI2BAUD = ICLK/8*9600+1 = 157  (0x9d)
  SCI2HBAUD = 0x0;
  SCI2MBAUD = 0x0;
  SCI2LBAUD = 0x9d;

  //Rx pin assign to Reveiver
  SCI2PC2_bit.RX_FUNC = 1;
  // Tx pin assign to Transmitter
  SCI2PC3_bit.TX_FUNC = 1;

  // Configure SCI1 state machine
  SCI2CTL3 |= 0x80;

}


// Write char to SCI
void SCI2_write_char(unsigned char ch) {
  while(!SCI2CTL2_bit.TXRDY);
  SCI2TXBUF = ch;
}

// Read char from SCI
unsigned char SCI2_read_char(void) {
  unsigned char ch = 0x0;
  while(!SCI2CTL1_bit.RXRDY);
  ch = SCI2RXBUF;
  return ch;
}

// Read char without stop
unsigned char SCI2_read_char_nonstop(void) {
  if(SCI2CTL1_bit.RXRDY)
    return SCI2RXBUF;
  else return 0;
}



// Turn on led
void LedON(void) {
  SCI1PC1_bit.CLK_DATA_OUT = 0;
}

// Turn off led
void LedOFF(void) {
    SCI1PC1_bit.CLK_DATA_OUT = 1;
}

